import setuptools

setuptools.setup(
    name='linwenkai',
    version='0.0.1',
    author='linwk',
    author_email='2259214992@qq.com',
    description='my first try',
    long_description='text/markdown',
    packages=setuptools.find_packages(),
    url="http://github.com/", ## 项目主页
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent"
    ]
)